# Changelog

## [Version: 0.3.1] - 2025-07-12

### Added

- Initial implementation of the configuration parser.
- Initial logic for mirroring repositories.

### Changed

- No changes in this release.

### Fixed

- No bug fixes in this release.

---

## [Version: 0.3.2] - 2025-11-05

### Added

- No new features introduced in this release.

### Changed

- Updated configuration settings for the primary logging system.

### Fixed

- No bug fixes in this release.

---

## [Version: 0.3.3] - 2026-02-19

### Added

- Added `--verbosity` to specify the logging level that controls which messages are displayed.
- Added the ability to change configurations using the command-line interface.

### Changed

- Removed `--debug` from the command-line interface.
- Some logger messages have been modified to make them more readable and avoid ambiguous contexts.

### Fixed

- No bug fixes in this release.
